[cig-commits] [commit] kommu/aspect-citcom-benchmarks: Added the volume_avg flag to the Output structure to control the output of <T> and <V_rms> (48947d1)

cig_noreply at geodynamics.org cig_noreply at geodynamics.org
Tue Apr 8 03:01:03 PDT 2014


Repository : ssh://geoshell/citcoms

On branch  : kommu/aspect-citcom-benchmarks
Link       : https://github.com/geodynamics/citcoms/compare/3ebabdc12f5b4e8d7db6edbc2cc578201d4477bf...fb1839e7e93bc56eb542afd64b3db70f2df6a5d8

>---------------------------------------------------------------

commit 48947d18b9c424d771f439c93a81852d52cae217
Author: Rajesh Kommu <rajesh.kommu at gmail.com>
Date:   Mon Mar 31 13:03:02 2014 -0700

    Added the volume_avg flag to the Output structure to control the output
    of <T> and <V_rms>


>---------------------------------------------------------------

48947d18b9c424d771f439c93a81852d52cae217
 lib/Instructions.c |  5 +++-
 lib/global_defs.h  | 74 ++++++++++++++++++++++++++++--------------------------
 2 files changed, 42 insertions(+), 37 deletions(-)

diff --git a/lib/Instructions.c b/lib/Instructions.c
index de19336..86000c8 100644
--- a/lib/Instructions.c
+++ b/lib/Instructions.c
@@ -1592,6 +1592,7 @@ static void output_parse_optional(struct  All_variables *E)
     E->output.botm = 0;
     E->output.geoid = 0;
     E->output.horiz_avg = 0;
+    E->output.volume_avg = 0;
     E->output.seismic = 0;
     E->output.coord_bin = 0;
     E->output.tracer = 0;
@@ -1636,7 +1637,9 @@ static void output_parse_optional(struct  All_variables *E)
 		E->output.geoid  = 1;
 	    }
         else if(strcmp(prev, "horiz_avg")==0)
-            E->output.horiz_avg = 1;
+	  E->output.horiz_avg = 1;
+	else if(strcmp(prev, "volume_avg") == 0)
+	  E->output.volume_avg = 1;
         else if(strcmp(prev, "seismic")==0) {
             E->output.seismic = E->output.coord_bin = 1;
 
diff --git a/lib/global_defs.h b/lib/global_defs.h
index a99cc67..35343d6 100644
--- a/lib/global_defs.h
+++ b/lib/global_defs.h
@@ -622,42 +622,44 @@ struct gzd_struc{
 
 };
 
-struct Output {
-    char format[20];  /* ascii or hdf5 */
-    char optional[1000]; /* comma-delimited list of objects to output */
-    char vtk_format[10]; /*ascii or binary */
-
-    int llmax;  /* max degree of spherical harmonics output */
-
-    /* size of collective buffer used by MPI-IO */
-    int cb_block_size;
-    int cb_buffer_size;
-
-    /* size of data sieve buffer used by HDF5 */
-    int sieve_buf_size;
-
-    /* memory alignment used by HDF5 */
-    int alignment;
-    int alignment_threshold;
-
-    /* cache for chunked dataset used by HDF5 */
-    int cache_mdc_nelmts;
-    int cache_rdcc_nelmts;
-    int cache_rdcc_nbytes;
-
-    int connectivity; /* whether to output connectivity */
-    int stress;       /* whether to output stress */
-    int pressure;     /* whether to output pressure */
-    int surf;         /* whether to output surface data */
-    int botm;         /* whether to output bottom data */
-    int geoid;        /* whether to output geoid/topo spherial harmonics */
-    int horiz_avg;    /* whether to output horizontal averaged profile */
-    int seismic;      /* whether to output seismic velocity model */
-    int coord_bin;    /* whether to output coordinates in binary format */
-    int tracer;       /* whether to output tracer coordinate */
-    int comp_el;      /* whether to output composition at elements */
-    int comp_nd;      /* whether to output composition at nodes */
-    int heating;      /* whether to output heating terms at elements */
+struct Output 
+{
+  char format[20];  /* ascii or hdf5 */
+  char optional[1000]; /* comma-delimited list of objects to output */
+  char vtk_format[10]; /*ascii or binary */
+
+  int llmax;  /* max degree of spherical harmonics output */
+
+  /* size of collective buffer used by MPI-IO */
+  int cb_block_size;
+  int cb_buffer_size;
+
+  /* size of data sieve buffer used by HDF5 */
+  int sieve_buf_size;
+
+  /* memory alignment used by HDF5 */
+  int alignment;
+  int alignment_threshold;
+
+  /* cache for chunked dataset used by HDF5 */
+  int cache_mdc_nelmts;
+  int cache_rdcc_nelmts;
+  int cache_rdcc_nbytes;
+
+  int connectivity; /* whether to output connectivity */
+  int stress;       /* whether to output stress */
+  int pressure;     /* whether to output pressure */
+  int surf;         /* whether to output surface data */
+  int botm;         /* whether to output bottom data */
+  int geoid;        /* whether to output geoid/topo spherial harmonics */
+  int horiz_avg;    /* whether to output horizontal averaged profile */
+  int volume_avg;   /* whether to output volume averaged profile */
+  int seismic;      /* whether to output seismic velocity model */
+  int coord_bin;    /* whether to output coordinates in binary format */
+  int tracer;       /* whether to output tracer coordinate */
+  int comp_el;      /* whether to output composition at elements */
+  int comp_nd;      /* whether to output composition at nodes */
+  int heating;      /* whether to output heating terms at elements */
 
 
   /* flags used by GZDIR */



More information about the CIG-COMMITS mailing list